// Leagcy Quadrature reader
/* A project that that will read and decode 4 or 5 quadrature inputs
 from a Legacy Ornamental Mill.
 Written by Brian C. Slater, starting on May 7, 2005
*/

/*
Limits:

X +/_ 6.2500 
Y 0-49.0000 
Z 0-2.5000 
A 000.00 to 359.9999
B 000.00 to 359.9999 not yet implimented
*/

module Legacy(CLK_0, LED,
	 Quad_X_A, Quad_X_B,
	 Quad_A_A, Quad_A_B,
	 Quad_Z_A, Quad_Z_B,
	 Quad_Y_A, Quad_Y_B,
	 Reset_NOT_X, Reset_NOT_Y, Reset_NOT_Z, Reset_NOT_A,
	 LCD_0, LCD_1, LCD_2, LCD_3, LCD_4, LCD_5, LCD_6, LCD_7, LCD_RS, LCD_E, LCD_RW
	);

parameter BITS_IN_PP	= 16; // # of bits of binary input

input CLK_0;

input Quad_X_A, Quad_X_B, Reset_NOT_X;
input Quad_Y_A, Quad_Y_B, Reset_NOT_Y;
input Quad_Z_A, Quad_Z_B, Reset_NOT_Z;
input Quad_A_A, Quad_A_B, Reset_NOT_A;

output LED;
output LCD_0, LCD_1, LCD_2, LCD_3, LCD_4, LCD_5, LCD_6, LCD_7, LCD_RS, LCD_E, LCD_RW;

reg [BITS_IN_PP-1:0] Count_X;
reg [BITS_IN_PP-1:0] Count_Y;
reg [BITS_IN_PP-1:0] Count_Z;
reg [BITS_IN_PP-1:0] Count_A;

assign LED = Count_X[2];//Just so I'll know something is happening, because I have an inferiority complex - is that OK with you!?

// The X section, obviously, this is where the Quad signals get sliced, diced, and counted
Quad_Read Quad_Read_X (.CLK_0 (CLK_0), .Count (Count_X),
	 .Quad_A (Quad_X_A), .Quad_B (Quad_X_B), .Reset (Reset_NOT_X));

// The Y section, obviously, this is where the Quad signals get sliced, diced, and counted
Quad_Read Quad_Read_Y (.CLK_0 (CLK_0), .Count (Count_Y),
	 .Quad_A (Quad_Y_A), .Quad_B (Quad_Y_B), .Reset (Reset_NOT_Y));

// The Z section, obviously, this is where the Quad signals get sliced, diced, and counted
Quad_Read Quad_Read_Z (.CLK_0 (CLK_0), .Count (Count_Z),
	 .Quad_A (Quad_Z_A), .Quad_B (Quad_Z_B), .Reset (Reset_NOT_Z));

// The A section, obviously, this is where the Quad signals get sliced, diced, and counted
Quad_Read Quad_Read_A (.CLK_0 (CLK_0), .Count (Count_A),
	 .Quad_A (Quad_A_A), .Quad_B (Quad_A_B), .Reset (Reset_NOT_A));

//This section converts the raw counts to binary hundredths of inches, binary to BCD and then to ASCII (adding hex 30)
// Then it displays the axis name, polarity, and the BCDs, with appropriate decimal point, on the LCD
Display_Legacy(.CLK_0(CLK_0),// .LED(LED),
	 .Count_X(Count_X), .Count_Y(Count_Y),
	 .Count_Z(Count_Z), .Count_A(Count_A),
	 .Reset_NOT(Reset_NOT_Z),
	 .LCD_0(LCD_0), .LCD_1(LCD_1), .LCD_2(LCD_2), .LCD_3(LCD_3),
	 .LCD_4(LCD_4), .LCD_5(LCD_5), .LCD_6(LCD_6), .LCD_7(LCD_7),
	 .LCD_RS(LCD_RS), .LCD_E(LCD_E), .LCD_RW(LCD_RW));

endmodule
